summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/widgets/tqradiobutton.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tqtinterface/qt4/src/widgets/tqradiobutton.cpp')
-rw-r--r--tqtinterface/qt4/src/widgets/tqradiobutton.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/tqtinterface/qt4/src/widgets/tqradiobutton.cpp b/tqtinterface/qt4/src/widgets/tqradiobutton.cpp
index 69bdedb..0ddddf8 100644
--- a/tqtinterface/qt4/src/widgets/tqradiobutton.cpp
+++ b/tqtinterface/qt4/src/widgets/tqradiobutton.cpp
@@ -156,17 +156,17 @@ void TQRadioButton::setChecked( bool check )
/*!
\reimp
*/
-TQSize TQRadioButton::tqsizeHint() const
+TQSize TQRadioButton::sizeHint() const
{
// Any more complex, and we will use tqstyle().tqitemRect()
// NB: TQCheckBox::tqsizeHint() is similar
constPolish();
TQPainter p(this);
TQSize sz = tqstyle().tqitemRect(&p, TQRect(0, 0, 1, 1), TQt::ShowPrefix, FALSE,
pixmap(), text()).size();
- return (tqstyle().tqsizeFromContents(TQStyle::CT_RadioButton, this, sz).
+ return (tqstyle().sizeFromContents(TQStyle::CT_RadioButton, this, sz).
expandedTo(TQApplication::globalStrut()));
}
@@ -321,7 +321,7 @@ void TQRadioButton::resizeEvent( TQResizeEvent* e )
TQPainter p(this);
TQSize isz = tqstyle().tqitemRect(&p, TQRect(0, 0, 1, 1), TQt::ShowPrefix, FALSE,
pixmap(), text()).size();
- TQSize wsz = (tqstyle().tqsizeFromContents(TQStyle::CT_RadioButton, this, isz).
+ TQSize wsz = (tqstyle().sizeFromContents(TQStyle::CT_RadioButton, this, isz).
expandedTo(TQApplication::globalStrut()));
update(wsz.width(), isz.width(), 0, wsz.height());
@@ -156,17 +156,17 @@ void TQRadioButton::setChecked( bool check )
{
// Any more complex, and we will use tqstyle().tqitemRect()
- // NB: TQCheckBox::tqsizeHint() is similar
+ // NB: TQCheckBox::sizeHint() is similar
constPolish();
TQPainter p(this);